pub struct ControlPlaneClient { /* private fields */ }Expand description
Control plane client that maintains connection and handles messages.
Implementations
Sourceimpl ControlPlaneClient
impl ControlPlaneClient
Sourcepub fn new(config: ControlPlaneConfig) -> Self
pub fn new(config: ControlPlaneConfig) -> Self
Create a new control plane client.
Sourcepub fn start(
self,
shutdown_rx: Receiver<bool>,
) -> (Receiver<ArtifactNotification>, Sender<ArtifactDownloadedResponse>)
pub fn start( self, shutdown_rx: Receiver<bool>, ) -> (Receiver<ArtifactNotification>, Sender<ArtifactDownloadedResponse>)
Start the connection loop in a background task. Returns a receiver for artifact notifications and a sender for download responses.