Dev server file watcher.
Watches spec files, manifest, and local plugin WASM files for changes,
bridging notify events to a tokio channel with debouncing.
Structs
- DevWatcher
- File watcher for the dev server.
Dev server file watcher.
Watches spec files, manifest, and local plugin WASM files for changes,
bridging notify events to a tokio channel with debouncing.